Camelot Shortcuts — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot Documentation contents »
- Camelot Documentation »

# Camelot Shortcuts

Release: | trunk
Date: | November 03, 2011

This page contains the various shortcuts available in Camelot and their meanings. Camelot graphical user interface (GUI) is based on PyQt4 widgets, which are themselve based on Qt4. Qt4 defines what is called actions, which are basically common commands that can be invoked via menus, toolbar buttons, and keyboard shortcuts.

Qt4 (and thus PyQt4) comes with a set of standard shortcuts (through the convenience enumeration [QKeySequence.StandardKey] [1]) for various widgets. It is possible then that a keyboard shortcut not mentioned here performs a desirable action by default.

[1]: http://doc.trolltech.com/4.4/qkeysequence.html#StandardKey-enum

Following are the shortcuts available in Camelot.

Note

On Mac OS X, the Ctrl value corresponds to the key Command on the Macintosh keyboard.

## Main window shortcuts

> `Alt-Spacebar` | Display control menu for the main window
> `Ctrl-p` | Print
> `Alt-f v` | Preview (todo)

### Menus shortcuts

> `F10`, `Alt` | Select the menu bar
> `Up`, `Down`, `Left`, `Right` | Navigate the menu bar
> `Tab` | When menu bar is selected, go to next menu
> `Shift-Tab` | When menu bar is selected, go to previous menu
> `ENTER` | Perform the action or open selected menu

### Navigation pane shortcuts

> `Up`, `Down` | Navigate the entities tree
> `ENTER` | Open selected entity (todo)

## Child windows shortcuts

> `Ctrl-W`, `Ctrl+F4` | Close the selected child window (todo)
> `Ctrl-F5` | Restore window size of selected window (todo)
> `Ctrl-Tab` | Switch next child window (todo)
> `Ctrl-Shift-Tab` | Switch to previous child window (todo)
> `F9` | Session refresh
> `Ctrl-F9` | Minimize child window (todo)
> `Ctrl-F10` | Maximize child window (todo)

### Table view shortcuts

> `Up`, `Down` | Navigate rows
> `Tab` | Next cell
> `Shift-Tab` | Previous cell
> `Ctrl-Home` | First row in the column
> `Ctrl-End` | Last row in the column
> `Alt-Home` | First cell in the row
> `Alt-End` | Last cell in the row
> `Ctrl-Alt-Home` | First cell of first row
> `Ctrl-Alt-End` | Last cell of last row

### Form view shortcuts

> `Ctrl-z` | Undo
> `Ctrl-c` | Copy
> `Ctrl-x` | Cut
> `Ctrl-v` | Paste
> `Delete` | Delete
> `Ctrl-b` | Format bold
> `Ctrl-i` | Format italic

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot Documentation contents »
- Camelot Documentation »

Comments
blog comments powered by Disqus